import request from '@/utils/request'

// 获取首页数据
export function loadIndexs(data) {
	return request({
		url: '/api/big_screen',
		method: 'get',
		params: data
	});
}

// 播报订单信息
export function play(data, id) {
	return request({
		url: '/api/store/order/play/' + id,
		method: 'post',
		params: data
	});
}

// 过万大神
export function over10000(data) {
	return request({
		url: '/api/over10000',
		method: 'get',
		data
	});
}

// 员工排行榜
export function waiter_rank(data) {
	return request({
		url: '/api/waiter_rank',
		method: 'get',
		data
	});
}
// 订单列表
export function order(data) {
	return request({
		url: '/api/store/order',
		method: 'get',
		data
	});
}

//门店列表 
export function store_list(data) {
	return request({
		url: '/api/store/list',
		method: 'get',
		data
	});
}

//门店详情
export function store(data, id) {
	return request({
		url: '/api/store/detail/' + id,
		method: 'get',
		data
	});
}

//商品排名
export function product(data) {
	return request({
		url: '/api/see/product',
		method: 'get',
		data
	});
}

// 推广海报二维码生成
export function spreadBanner(data) {
	return request({
		url: '/api/spread/banner',
		method: 'get',
		data
	});
}

// 绑定店员
export function set_waiter(data) {
	return request({
		url: '/api/set_waiter',
		method: 'post',
		data
	});
}

//小组列表
export function groupList(data) {
	return request({
		url: '/api/group/list',
		method: 'get',
		data
	});
}

// 个人裂变排行榜
export function user_explode_rank(data) {
	return request({
		url: '/api/user_explode_rank',
		method: 'get',
		params: data
	});
}

// 门店裂变排行
export function store_explode_rank(data) {
	return request({
		url: '/api/store_explode_rank',
		method: 'get',
		params: data
	});
}

// 超级客户
export function super_user(data) {
	return request({
		url: '/api/super_user',
		method: 'get',
		params: data
	});
}


// 小组裂变金额排行
export function group_explode_rank(data) {
	return request({
		url: '/api/group_explode_rank',
		method: 'get',
		params: data
	});
}
